@@ -1,13 +1,14 @@
+from __future__ import annotations
 import logging
 import datetime
-from typing import Callable, Union
+from collections.abc import Callable
 from functools import wraps
 
 
 def log_function_call(function: Callable) -> Callable:
     """
-    This function should be used as a decorator to log the function name and paramters of the function when
-    called.
+    This function should be used as a decorator to log the function name and paramters of the
+    function when called.
 
     Args: function that is decorated
     """
@@ -28,17 +29,17 @@ def log_function_call(function: Callable) -> Callable:
     return wrapper
 
 
-def _log_function(function_name: str, params: Union[dict, None] = None):
+def _log_function(function_name: str, params: dict | None = None):
     """
-    This function is meant to be used at the start of the calling function; calls logging.info and passes the
-    name of the function and optional parameter names/values.
+    This function is meant to be used at the start of the calling function; calls logging.info and
+    passes the name of the function and optional parameter names/values.
 
     Args:
         func_name:
             the name of the function
         params:
-            a dictionary containing the names of the function parameters (as dictionary keys) and the
-            parameter values (as dictionary values).
+            a dictionary containing the names of the function parameters (as dictionary keys) and
+            the parameter values (as dictionary values).
     """
     logging.info(f"FUNCTION: {function_name.upper()}")
     if params is not None:
@@ -51,9 +52,14 @@ class Timer:
     """
     This class provides way to time the duration of code within the context manager.
     """
-    def __init__(self, message, include_message_at_finish=False):
+    def __init__(self, message: str, post_message: bool = False):
+        """
+        Args:
+            message: message to show when timer starts
+            post_message: if True, include same message when timer ends.
+        """
         self._message = message
-        self._include_message_at_finish = include_message_at_finish
+        self._post_message = post_message
 
     def __enter__(self):
         logging.basicConfig()
@@ -65,15 +71,20 @@ class Timer:
         self._end = datetime.datetime.now()
         self._interval = self._end - self._start
         message = ''
-        if self._include_message_at_finish:
+        if self._post_message:
             message = self._message + " "
         logging.info(f'Timer Finished: {message}({self._interval.total_seconds():.2f} seconds)')
 
 
 def log_timer(function: Callable) -> Callable:
+    """
+    This function should be used as a decorator to log the time/duration of a function call.
+
+    Args: function that is decorated
+    """
     @wraps(function)
     def wrapper(*args, **kwargs):
-        with Timer(f"FUNCTION={function.__module__}:{function.__name__}", include_message_at_finish=True):
+        with Timer(f"FUNCTION={function.__module__}:{function.__name__}", post_message=True):
             results = function(*args, **kwargs)
         return results
 
